pub enum NormalForm {
Unaliased,
PixelPacked,
ImagePacked,
RowMajorPacked,
ColumnMajorPacked,
}Expand description
Different normal forms of buffers.
A normal form is an unaliased buffer with some additional constraints. The ÌmageBuffer uses
row major form with packed samples.
Variants
Unaliased
No pixel aliases another.
Unaliased also guarantees that all index calculations in the image bounds using
dim_index*dim_stride (such as x*width_stride + y*height_stride) do not overflow.
PixelPacked
At least pixels are packed.
Images of these types can wrap [T]-slices into the standard color types. This is a
precondition for GenericImage which requires by-reference access to pixels.
ImagePacked
All samples are packed.
This is orthogonal to PixelPacked. It requires that there are no holes in the image but
it is not necessary that the pixel samples themselves are adjacent. An example of this
behaviour is a planar image layout.
RowMajorPacked
The samples are in row-major form and all samples are packed.
In addition to PixelPacked and ImagePacked this also asserts that the pixel matrix is
in row-major form.
ColumnMajorPacked
The samples are in column-major form and all samples are packed.
In addition to PixelPacked and ImagePacked this also asserts that the pixel matrix is
in column-major form.